==> haskell-cracknum-2.2-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cracknum.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crackNum
version: 2.2
id: crackNum-2.2-AypkWvbxZ2j5fO179To6Ek
key: crackNum-2.2-AypkWvbxZ2j5fO179To6Ek
license: BSD-3-Clause
copyright: Levent Erkok
maintainer: erkokl@gmail.com
author: Levent Erkok
homepage: http://github.com/LeventErkok/CrackNum
synopsis: Crack various integer, floating-point data formats
description:
    Crack HP, SP and DP floats and 8, 16, 32, 64 bit words and integers.
    .
    For details, please see: <http://github.com/LeventErkok/crackNum/>
category: Tools
abi: d2a4fcd3fb3469092b9ee58568bbc967
exposed: True
exposed-modules:
    Data.Numbers.CrackNum
hidden-modules: Data.Numbers.CrackNum.Utils
                Data.Numbers.CrackNum.Data
import-dirs: /usr/lib/ghc-8.4.3/site-local/crackNum-2.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/crackNum-2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/crackNum-2.2
hs-libraries: HScrackNum-2.2-AypkWvbxZ2j5fO179To6Ek
depends:
    base-4.11.1.0 ieee754-0.8.0-KmEF4YGiqmIDu40b1SLx46
    reinterpret-cast-0.1.0-xiDWf9kNat3fuSwGQ1k15
    FloatingHex-0.4-KYnoa1TeuOP3FBMKHxfwLf
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             ieee754-0.8.0-KmEF4YGiqmIDu40b1SLx46=58ee7693c3f851924adb1977b480388a
             reinterpret-cast-0.1.0-xiDWf9kNat3fuSwGQ1k15=8e01d44f814c7ed89b54ed94ee8b6b64
             FloatingHex-0.4-KYnoa1TeuOP3FBMKHxfwLf=55f7a4110122120c9cf51b579c32eb56
haddock-interfaces: /usr/share/doc/haskell-cracknum/html/crackNum.haddock
haddock-html: /usr/share/doc/haskell-cracknum/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cracknum-2.2-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cracknum.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crackNum
version: 2.2
id: crackNum-2.2-28dK4Jt3DjmGDZUbzqzXHA
key: crackNum-2.2-28dK4Jt3DjmGDZUbzqzXHA
license: BSD-3-Clause
copyright: Levent Erkok
maintainer: erkokl@gmail.com
author: Levent Erkok
homepage: http://github.com/LeventErkok/CrackNum
synopsis: Crack various integer, floating-point data formats
description:
    Crack HP, SP and DP floats and 8, 16, 32, 64 bit words and integers.
    .
    For details, please see: <http://github.com/LeventErkok/crackNum/>
category: Tools
abi: 75a88b210206cec8006c8beb9cebf10f
exposed: True
exposed-modules:
    Data.Numbers.CrackNum
hidden-modules: Data.Numbers.CrackNum.Utils
                Data.Numbers.CrackNum.Data
import-dirs: /usr/lib/ghc-8.4.3/site-local/crackNum-2.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/crackNum-2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/crackNum-2.2
hs-libraries: HScrackNum-2.2-28dK4Jt3DjmGDZUbzqzXHA
depends:
    base-4.11.1.0 ieee754-0.8.0-KmEF4YGiqmIDu40b1SLx46
    reinterpret-cast-0.1.0-E5ZUnNU3tPAIKVMpFT9Hb1
    FloatingHex-0.4-KYnoa1TeuOP3FBMKHxfwLf
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             ieee754-0.8.0-KmEF4YGiqmIDu40b1SLx46=58ee7693c3f851924adb1977b480388a
             reinterpret-cast-0.1.0-E5ZUnNU3tPAIKVMpFT9Hb1=63c3aa3875daa8857fda50769b242b9c
             FloatingHex-0.4-KYnoa1TeuOP3FBMKHxfwLf=55f7a4110122120c9cf51b579c32eb56
haddock-interfaces: /usr/share/doc/haskell-cracknum/html/crackNum.haddock
haddock-html: /usr/share/doc/haskell-cracknum/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
